==> adstax-sdk-scala_2.11-0.5.4-sources.jar: eu/shiftforward/adstax/ups/api/UserProfileStorageResponse.scala <==
package eu.shiftforward.adstax.ups.api

import spray.json.DefaultJsonProtocol._

/**
 * A response from the User Profile Storage module to a [[UserProfileStorageRequest]].
 */
sealed trait UserProfileStorageResponse

/**
 * The response for a [[GetUser]] request.
 *
 * @param data the attributes and segment values associated with the user wrapped in a `Some` if the user exists, `None`
 *             otherwise.
 */
case class GetUserResponse(data: Option[UserData]) extends UserProfileStorageResponse

object GetUserResponse {
  implicit val getResponseFormat = jsonFormat1(GetUserResponse.apply)
}

/**
 * The response for a [[GetUserBaseAttribute]] or a [[GetUserComputedAttribute]] request.
 *
 * @param attributeValue the attribute value for the requested key wrapped in a `Some` if the user and the attribute
 * exists, `None` otherwise
 */
case class GetUserAttributeResponse(attributeValue: Option[AttributeValue]) extends UserProfileStorageResponse

object GetUserAttributeResponse {
  implicit val getAttributeResponseFormat = jsonFormat1(GetUserAttributeResponse.apply)
}

/**
 * The response for an [[UpdateUser]] request.
 */
case object UpdateUserResponse extends UserProfileStorageResponse {
  implicit val updateResponseFormat = jsonFormat0(() => UpdateUserResponse)
}

/**
 * The response for a [[DeleteUser]] request.
 */
case object DeleteUserResponse extends UserProfileStorageResponse {
  implicit val deleteResponseFormat = jsonFormat0(() => DeleteUserResponse)
}

/**
 * The response for a [[DeleteUserAttribute]] request.
 */
case object DeleteUserAttributeResponse extends UserProfileStorageResponse {
  implicit val deleteAttributeResponseFormat = jsonFormat0(() => DeleteUserAttributeResponse)
}

/**
 * The response for a [[LinkUsers]] request.
 */
case object LinkUsersResponse extends UserProfileStorageResponse {
  implicit val linkResponseFormat = jsonFormat0(() => LinkUsersResponse)
}

/**
 * The response for a [[GetIds]] request.
 */
case class GetIdsResponse(ids: Set[UserId]) extends UserProfileStorageResponse

object GetIdsResponse {
  implicit val getIdsResponseFormat = jsonFormat1(GetIdsResponse.apply)
}

/**
 * The response for a [[ResetLinks]] request.
 */
case object ResetLinksResponse extends UserProfileStorageResponse {
  implicit val resetLinksResponseFormat = jsonFormat0(() => ResetLinksResponse)
}

==> adstax-sdk-scala_2.11-0.8.2-sources.jar: eu/shiftforward/adstax/ups/api/UserProfileStorageResponse.scala <==
package eu.shiftforward.adstax.ups.api

import spray.json.DefaultJsonProtocol._
import spray.json.JsValue

/**
 * A response from the User Profile Storage module to a [[UserProfileStorageRequest]].
 */
sealed trait UserProfileStorageResponse

/**
 * The response for a [[GetUser]] request.
 *
 * @param data the attributes and computed attributes values associated with the user wrapped in a `Some`
 *             if the user exists, `None` otherwise.
 */
case class GetUserResponse(data: Option[UserData]) extends UserProfileStorageResponse

object GetUserResponse {
  implicit val getResponseFormat = jsonFormat1(GetUserResponse.apply)
}

/**
 * The response for a [[GetIds]] request.
 */
case class GetIdsResponse(ids: Set[UserId]) extends UserProfileStorageResponse

object GetIdsResponse {
  implicit val getIdsResponseFormat = jsonFormat1(GetIdsResponse.apply)
}

/**
 * The response for a [[GetIdsAndData]] request.
 *
 * @param ids the set of ids associated with the user
 * @param data the attributes and computed attributes values associated with the user wrapped in a `Some`
 *             if the user exists, `None` otherwise.
 */
case class GetIdsAndDataResponse(ids: Set[UserId], data: Option[UserData]) extends UserProfileStorageResponse

object GetIdsAndDataResponse {
  implicit val getResponseFormat = jsonFormat2(GetIdsAndDataResponse.apply)
}

/**
 * The response for a [[GetUserBaseAttribute]] or a [[GetUserComputedAttribute]] request.
 *
 * @param attributeValue the attribute value for the requested key wrapped in a `Some` if the user and the attribute
 * exists, `None` otherwise
 */
case class GetUserAttributeResponse(attributeValue: Option[JsValue]) extends UserProfileStorageResponse

object GetUserAttributeResponse {
  implicit val getAttributeResponseFormat = jsonFormat1(GetUserAttributeResponse.apply)
}

/**
 * The response for an [[UpdateUser]] request.
 */
case object UpdateUserResponse extends UserProfileStorageResponse {
  implicit val updateResponseFormat = jsonFormat0(() => UpdateUserResponse)
}

/**
 * The response for a [[DeleteUser]] request.
 */
case object DeleteUserResponse extends UserProfileStorageResponse {
  implicit val deleteResponseFormat = jsonFormat0(() => DeleteUserResponse)
}

/**
 * The response for a [[DeleteUserAttribute]] request.
 */
case object DeleteUserAttributeResponse extends UserProfileStorageResponse {
  implicit val deleteAttributeResponseFormat = jsonFormat0(() => DeleteUserAttributeResponse)
}

/**
 * The response for a [[LinkUsers]] request.
 */
case object LinkUsersResponse extends UserProfileStorageResponse {
  implicit val linkResponseFormat = jsonFormat0(() => LinkUsersResponse)
}

/**
 * The response for a [[SetMergeStrategy]] request.
 */
case object SetMergeStrategyResponse extends UserProfileStorageResponse {
  implicit val setMergeStrategyResponseFormat = jsonFormat0(() => SetMergeStrategyResponse)
}

/**
 * The response for a [[ResetLinks]] request.
 */
case object ResetLinksResponse extends UserProfileStorageResponse {
  implicit val resetLinksResponseFormat = jsonFormat0(() => ResetLinksResponse)
}
